==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Combinatorial_map/group__PkgCombinatorialMapsClasses.js <==
var group__PkgCombinatorialMapsClasses =
[
    [ "Cell_attribute", "classCGAL_1_1Cell__attribute.html", [
      [ "Dart_const_descriptor", "classCGAL_1_1Cell__attribute.html#adc064077e4a355927e33f8639a86cb0e", null ],
      [ "Dart_descriptor", "classCGAL_1_1Cell__attribute.html#a6db5d80029aa2394172a2044837faf9c", null ],
      [ "Info", "classCGAL_1_1Cell__attribute.html#aaeb15cbee006821f499c176e23629c88", null ],
      [ "On_merge", "classCGAL_1_1Cell__attribute.html#ac35d9fc2a5f13bd0f205b6505abfa388", null ],
      [ "On_split", "classCGAL_1_1Cell__attribute.html#ad5e168a0c0be9a180fddfacbae5a0b78", null ],
      [ "Supports_cell_dart", "classCGAL_1_1Cell__attribute.html#aa1765764650b208952d151d86fb1ae12", null ]
    ] ],
    [ "Cell_attribute_with_id", "classCGAL_1_1Cell__attribute__with__id.html", [
      [ "id", "classCGAL_1_1Cell__attribute__with__id.html#a2c83380959c48e30108a76fabf685739", null ],
      [ "id", "classCGAL_1_1Cell__attribute__with__id.html#a6d8e49c96ddbd71c2a42c3592903b228", null ]
    ] ],
    [ "Combinatorial_map", "classCGAL_1_1Combinatorial__map.html", [
      [ "Attributes", "classCGAL_1_1Combinatorial__map.html#afad703e90b77a98eb8518a8a869fa4df", null ],
      [ "Dart_info", "classCGAL_1_1Combinatorial__map.html#abb2097ef08059b670fa9177dfafb1a5e", null ],
      [ "Self", "classCGAL_1_1Combinatorial__map.html#a959bf5a18d5bc002af4ea4717c34862c", null ],
      [ "dimension", "classCGAL_1_1Combinatorial__map.html#ac339cc6e3682f002522e46389f5dae9b", null ]
    ] ],
    [ "Generic_map_min_items", "structCGAL_1_1Generic__map__min__items.html", null ]
];

==> CGAL-6.0-doc_html.tar.xz: doc_html/Combinatorial_map/group__PkgCombinatorialMapsClasses.js <==
var group__PkgCombinatorialMapsClasses =
[
    [ "CGAL::Cell_attribute< Map, Info_, Tag, OnMerge, OnSplit >", "classCGAL_1_1Cell__attribute.html", [
      [ "Dart_const_descriptor", "classCGAL_1_1Cell__attribute.html#adc064077e4a355927e33f8639a86cb0e", null ],
      [ "Dart_descriptor", "classCGAL_1_1Cell__attribute.html#a6db5d80029aa2394172a2044837faf9c", null ],
      [ "Info", "classCGAL_1_1Cell__attribute.html#aaeb15cbee006821f499c176e23629c88", null ],
      [ "On_merge", "classCGAL_1_1Cell__attribute.html#ac35d9fc2a5f13bd0f205b6505abfa388", null ],
      [ "On_split", "classCGAL_1_1Cell__attribute.html#ad5e168a0c0be9a180fddfacbae5a0b78", null ],
      [ "Supports_cell_dart", "classCGAL_1_1Cell__attribute.html#aa1765764650b208952d151d86fb1ae12", null ]
    ] ],
    [ "CGAL::Cell_attribute_with_id< Map, Info_, Tag, OnMerge, OnSplit >", "classCGAL_1_1Cell__attribute__with__id.html", [
      [ "id", "classCGAL_1_1Cell__attribute__with__id.html#a3d81ce98f5ddfe823d19238040f727b8", null ],
      [ "id", "classCGAL_1_1Cell__attribute__with__id.html#a2c83380959c48e30108a76fabf685739", null ]
    ] ],
    [ "CGAL::Combinatorial_map< d, Items, Alloc >", "classCGAL_1_1Combinatorial__map.html", [
      [ "Attributes", "classCGAL_1_1Combinatorial__map.html#afad703e90b77a98eb8518a8a869fa4df", null ],
      [ "Dart_info", "classCGAL_1_1Combinatorial__map.html#abb2097ef08059b670fa9177dfafb1a5e", null ],
      [ "Self", "classCGAL_1_1Combinatorial__map.html#a959bf5a18d5bc002af4ea4717c34862c", null ],
      [ "dimension", "classCGAL_1_1Combinatorial__map.html#ac339cc6e3682f002522e46389f5dae9b", null ]
    ] ],
    [ "CGAL::Generic_map_min_items", "structCGAL_1_1Generic__map__min__items.html", null ]
];
